/*
 * Written by Sean Kelly
 * Placed into Public Domain
 */

module std.c.errno;

extern (C):

extern int errno;

version( Win32 )
{
    const int EPERM             = 1;        // Operation not permitted
    const int ENOENT            = 2;        // No such file or directory
    const int ESRCH             = 3;        // No such process
    const int EINTR             = 4;        // Interrupted system call
    const int EIO               = 5;        // I/O error
    const int ENXIO             = 6;        // No such device or address
    const int E2BIG             = 7;        // Argument list too long
    const int ENOEXEC           = 8;        // Exec format error
    const int EBADF             = 9;        // Bad file number
    const int ECHILD            = 10;       // No child processes
    const int EAGAIN            = 11;       // Try again
    const int ENOMEM            = 12;       // Out of memory
    const int EACCES            = 13;       // Permission denied
    const int EFAULT            = 14;       // Bad address
    const int EBUSY             = 16;       // Device or resource busy
    const int EEXIST            = 17;       // File exists
    const int EXDEV             = 18;       // Cross-device link
    const int ENODEV            = 19;       // No such device
    const int ENOTDIR           = 20;       // Not a directory
    const int EISDIR            = 21;       // Is a directory
    const int EINVAL            = 22;       // Invalid argument
    const int ENFILE            = 23;       // File table overflow
    const int EMFILE            = 24;       // Too many open files
    const int ENOTTY            = 25;       // Not a typewriter
    const int EFBIG             = 27;       // File too large
    const int ENOSPC            = 28;       // No space left on device
    const int ESPIPE            = 29;       // Illegal seek
    const int EROFS             = 30;       // Read-only file system
    const int EMLINK            = 31;       // Too many links
    const int EPIPE             = 32;       // Broken pipe
    const int EDOM              = 33;       // Math argument out of domain of func
    const int ERANGE            = 34;       // Math result not representable
    const int EDEADLK           = 36;       // Resource deadlock would occur
    const int ENAMETOOLONG      = 38;       // File name too long
    const int ENOLCK            = 39;       // No record locks available
    const int ENOSYS            = 40;       // Function not implemented
    const int ENOTEMPTY         = 41;       // Directory not empty
    const int EILSEQ            = 42;       // Illegal byte sequence

    const int EDEADLOCK         = EDEADLK;
}
else version( linux )
{
    // Linux errno values
    // From /usr/include/asm-generic/errno-base.h
    const int EPERM             = 1;        // Operation not permitted
    const int ENOENT            = 2;        // No such file or directory
    const int ESRCH             = 3;        // No such process
    const int EINTR             = 4;        // Interrupted system call
    const int EIO               = 5;        // I/O error
    const int ENXIO             = 6;        // No such device or address
    const int E2BIG             = 7;        // Argument list too long
    const int ENOEXEC           = 8;        // Exec format error
    const int EBADF             = 9;        // Bad file number
    const int ECHILD            = 10;       // No child processes
    const int EAGAIN            = 11;       // Try again
    const int ENOMEM            = 12;       // Out of memory
    const int EACCES            = 13;       // Permission denied
    const int EFAULT            = 14;       // Bad address
    const int ENOTBLK           = 15;       // Block device required
    const int EBUSY             = 16;       // Device or resource busy
    const int EEXIST            = 17;       // File exists
    const int EXDEV             = 18;       // Cross-device link
    const int ENODEV            = 19;       // No such device
    const int ENOTDIR           = 20;       // Not a directory
    const int EISDIR            = 21;       // Is a directory
    const int EINVAL            = 22;       // Invalid argument
    const int ENFILE            = 23;       // File table overflow
    const int EMFILE            = 24;       // Too many open files
    const int ENOTTY            = 25;       // Not a typewriter
    const int ETXTBSY           = 26;       // Text file busy
    const int EFBIG             = 27;       // File too large
    const int ENOSPC            = 28;       // No space left on device
    const int ESPIPE            = 29;       // Illegal seek
    const int EROFS             = 30;       // Read-only file system
    const int EMLINK            = 31;       // Too many links
    const int EPIPE             = 32;       // Broken pipe
    const int EDOM              = 33;       // Math argument out of domain of func
    const int ERANGE            = 34;       // Math result not representable

    // From /usr/include/asm-generic/errno.h
    const int EDEADLK           = 35;       // Resource deadlock would occur
    const int ENAMETOOLONG      = 36;       // File name too long
    const int ENOLCK            = 37;       // No record locks available
    const int ENOSYS            = 38;       // Function not implemented
    const int ENOTEMPTY         = 39;       // Directory not empty
    const int ELOOP             = 40;       // Too many symbolic links encountered
    const int EWOULDBLOCK       = EAGAIN;   // Operation would block
    const int ENOMSG            = 42;       // No message of desired type
    const int EIDRM             = 43;       // Identifier removed
    const int ECHRNG            = 44;       // Channel number out of range
    const int EL2NSYNC          = 45;       // Level 2 not synchronized
    const int EL3HLT            = 46;       // Level 3 halted
    const int EL3RST            = 47;       // Level 3 reset
    const int ELNRNG            = 48;       // Link number out of range
    const int EUNATCH           = 49;       // Protocol driver not attached
    const int ENOCSI            = 50;       // No CSI structure available
    const int EL2HLT            = 51;       // Level 2 halted
    const int EBADE             = 52;       // Invalid exchange
    const int EBADR             = 53;       // Invalid request descriptor
    const int EXFULL            = 54;       // Exchange full
    const int ENOANO            = 55;       // No anode
    const int EBADRQC           = 56;       // Invalid request code
    const int EBADSLT           = 57;       // Invalid slot

    const int EDEADLOCK         = EDEADLK;

    const int EBFONT            = 59;       // Bad font file format
    const int ENOSTR            = 60;       // Device not a stream
    const int ENODATA           = 61;       // No data available
    const int ETIME             = 62;       // Timer expired
    const int ENOSR             = 63;       // Out of streams resources
    const int ENONET            = 64;       // Machine is not on the network
    const int ENOPKG            = 65;       // Package not installed
    const int EREMOTE           = 66;       // Object is remote
    const int ENOLINK           = 67;       // Link has been severed
    const int EADV              = 68;       // Advertise error
    const int ESRMNT            = 69;       // Srmount error
    const int ECOMM             = 70;       // Communication error on send
    const int EPROTO            = 71;       // Protocol error
    const int EMULTIHOP         = 72;       // Multihop attempted
    const int EDOTDOT           = 73;       // RFS specific error
    const int EBADMSG           = 74;       // Not a data message
    const int EOVERFLOW         = 75;       // Value too large for defined data type
    const int ENOTUNIQ          = 76;       // Name not unique on network
    const int EBADFD            = 77;       // File descriptor in bad state
    const int EREMCHG           = 78;       // Remote address changed
    const int ELIBACC           = 79;       // Can not access a needed shared library
    const int ELIBBAD           = 80;       // Accessing a corrupted shared library
    const int ELIBSCN           = 81;       // .lib section in a.out corrupted
    const int ELIBMAX           = 82;       // Attempting to link in too many shared libraries
    const int ELIBEXEC          = 83;       // Cannot exec a shared library directly
    const int EILSEQ            = 84;       // Illegal byte sequence
    const int ERESTART          = 85;       // Interrupted system call should be restarted
    const int ESTRPIPE          = 86;       // Streams pipe error
    const int EUSERS            = 87;       // Too many users
    const int ENOTSOCK          = 88;       // Socket operation on non-socket
    const int EDESTADDRREQ      = 89;       // Destination address required
    const int EMSGSIZE          = 90;       // Message too long
    const int EPROTOTYPE        = 91;       // Protocol wrong type for socket
    const int ENOPROTOOPT       = 92;       // Protocol not available
    const int EPROTONOSUPPORT   = 93;       // Protocol not supported
    const int ESOCKTNOSUPPORT   = 94;       // Socket type not supported
    const int EOPNOTSUPP        = 95;       // Operation not supported on transport endpoint
    const int EPFNOSUPPORT      = 96;       // Protocol family not supported
    const int EAFNOSUPPORT      = 97;       // Address family not supported by protocol
    const int EADDRINUSE        = 98;       // Address already in use
    const int EADDRNOTAVAIL     = 99;       // Cannot assign requested address
    const int ENETDOWN          = 100;      // Network is down
    const int ENETUNREACH       = 101;      // Network is unreachable
    const int ENETRESET         = 102;      // Network dropped connection because of reset
    const int ECONNABORTED      = 103;      // Software caused connection abort
    const int ECONNRESET        = 104;      // Connection reset by peer
    const int ENOBUFS           = 105;      // No buffer space available
    const int EISCONN           = 106;      // Transport endpoint is already connected
    const int ENOTCONN          = 107;      // Transport endpoint is not connected
    const int ESHUTDOWN         = 108;      // Cannot send after transport endpoint shutdown
    const int ETOOMANYREFS      = 109;      // Too many references: cannot splice
    const int ETIMEDOUT         = 110;      // Connection timed out
    const int ECONNREFUSED      = 111;      // Connection refused
    const int EHOSTDOWN         = 112;      // Host is down
    const int EHOSTUNREACH      = 113;      // No route to host
    const int EALREADY          = 114;      // Operation already in progress
    const int EINPROGRESS       = 115;      // Operation now in progress
    const int ESTALE            = 116;      // Stale NFS file handle
    const int EUCLEAN           = 117;      // Structure needs cleaning
    const int ENOTNAM           = 118;      // Not a XENIX named type file
    const int ENAVAIL           = 119;      // No XENIX semaphores available
    const int EISNAM            = 120;      // Is a named type file
    const int EREMOTEIO         = 121;      // Remote I/O error
    const int EDQUOT            = 122;      // Quota exceeded

    const int ENOMEDIUM         = 123;      // No medium found
    const int EMEDIUMTYPE       = 124;      // Wrong medium type
    const int ECANCELED         = 125;      // Operation Canceled
    const int ENOKEY            = 126;      // Required key not available
    const int EKEYEXPIRED       = 127;      // Key has expired
    const int EKEYREVOKED       = 128;      // Key has been revoked
    const int EKEYREJECTED      = 129;      // Key was rejected by service

    // for robust mutexes
    const int EOWNERDEAD        = 130;      // Owner died
    const int ENOTRECOVERABLE   = 131;      // State not recoverable
}