# Makefile to build D runtime library dmdgc.a for Linux
# Designed to work with GNU make
# Targets:
#	make
#		Same as make all
#	make lib
#		Build dmdgc.a
#   make doc
#       Generate documentation
#	make clean
#		Delete unneeded files created by build process

CP=cp -f
RM=rm -f
MD=mkdir -p

#CFLAGS=-mn -6 -r
#CFLAGS=-g -mn -6 -r

DFLAGS=-release -O -inline -version=Posix -I../ares
#DFLAGS=-g -release -version=Posix -I../ares

TFLAGS=-O -inline -version=Posix -I../ares
#TFLAGS=-g -version=Posix -I../ares


CC=gcc
LC=$(AR)
DC=dmd

DOC_DEST=../../doc/dmdgc
LIB_DEST=../../lib

.SUFFIXES: .asm .c .cpp .d .html .o

.asm.o:
	$(CC) -c $<

.c.o:
	$(CC) -c $(CFLAGS) $< -o$@

.cpp.o:
	g++ -c $(CFLAGS) $< -o$@

.d.o:
	$(DC) -c $(DFLAGS) $< -of$@

.d.html:
	$(DC) -c $(DFLAGS) -o- -version=DDoc -Df$*.html dmdgc.ddoc $<

targets : lib doc
all     : lib doc
dmdgc   : lib
lib     : dmdgc.a
doc     : dmdgc.doc

######################################################

ALL_OBJS= \
    gc.o \
    gcbits.o \
    gclinux.o \
    gcstats.o \
    gcx.o

######################################################

ALL_DOCS=

######################################################

dmdgc.a : $(ALL_OBJS)
	$(RM) $@
	$(LC) -r $@ $(ALL_OBJS)

dmdgc.doc : $(ALL_DOCS)
#	$(MD) $(DOC_DEST)
#	$(CP) *.html $(DOC_DEST)/.
#	echo No documentation available.

######################################################

clean :
	$(RM) $(ALL_OBJS)
	$(RM) dmdgc*.a
	$(RM) $(ALL_DOCS)

install :
	$(CP) dmdgc*.a $(LIB_DEST)/.
